@@ -5,19 +5,19 @@ RPC Client services for IPC module.
 from .client import DjangoCfgRPCClient
 from .config import DjangoCfgRPCConfig
 from .exceptions import (
+    RPCBaseException,
+    RPCConfigurationError,
     RPCConnectionError,
-    RPCError,
-    RPCInternalError,
-    RPCInvalidMethodError,
+    RPCRemoteError,
     RPCTimeoutError,
 )
 
 __all__ = [
     'DjangoCfgRPCClient',
     'DjangoCfgRPCConfig',
-    'RPCError',
+    'RPCBaseException',
+    'RPCConfigurationError',
     'RPCConnectionError',
+    'RPCRemoteError',
     'RPCTimeoutError',
-    'RPCInvalidMethodError',
-    'RPCInternalError',
 ]
