@@ -2,12 +2,11 @@
 Base models for knowledge base application.
 """
 
-from django.db import models
-from django.contrib.auth import get_user_model
-from django.conf import settings
-from enum import Enum
 import uuid
 
+from django.conf import settings
+from django.db import models
+
 
 class ProcessingStatus(models.TextChoices):
     """Document processing status enumeration."""
@@ -20,21 +19,21 @@ class ProcessingStatus(models.TextChoices):
 
 class TimestampedModel(models.Model):
     """Base model with automatic timestamps."""
-    
+
     id = models.UUIDField(
-        primary_key=True, 
-        default=uuid.uuid4, 
+        primary_key=True,
+        default=uuid.uuid4,
         editable=False
     )
     created_at = models.DateTimeField(auto_now_add=True, db_index=True)
     updated_at = models.DateTimeField(auto_now=True)
-    
+
     class Meta:
         abstract = True
         indexes = [
             models.Index(fields=['-created_at']),
         ]
-    
+
     @property
     def short_uuid(self) -> str:
         """Return first 6 characters of UUID for display."""
@@ -43,14 +42,14 @@ class TimestampedModel(models.Model):
 
 class UserScopedModel(TimestampedModel):
     """Base model with user isolation."""
-    
+
     user = models.ForeignKey(
-        settings.AUTH_USER_MODEL, 
-        on_delete=models.CASCADE, 
+        settings.AUTH_USER_MODEL,
+        on_delete=models.CASCADE,
         db_index=True,
         help_text="Owner of this record"
     )
-    
+
     class Meta:
         abstract = True
         indexes = [
