@@ -4,34 +4,34 @@ Archive processing services.
 Decomposed services for document archive processing with proper separation of concerns.
 """
 
-from .exceptions import *
 from .archive_service import *
-from .extraction_service import *
 from .chunking_service import *
+from .context import ChunkContextBuilder, ChunkContextMetadata, ChunkData
+from .exceptions import *
+from .extraction_service import *
 from .vectorization_service import *
-from .context import ChunkContextBuilder, ChunkData, ChunkContextMetadata
 
 __all__ = [
     # Main archive service
     'DocumentArchiveService',
     'ArchiveUploadRequest',
     'ArchiveProcessingResult',
-    
+
     # Extraction services
     'ArchiveExtractionService',
     'ContentExtractionService',
     'ExtractedItemData',
-    
+
     # Chunking services
     'ContextualChunkingService',
     'ChunkContextBuilder',
     'ChunkData',
     'ChunkContextMetadata',
-    
+
     # Vectorization services
     'ArchiveVectorizationService',
     'VectorizationResult',
-    
+
     # Exceptions
     'ArchiveProcessingError',
     'ArchiveValidationError',
