@@ -1,5 +1,5 @@
 """
-Payment managers for the Universal Payment System v2.0.
+Payment managers for Payments v2.0.
 
 Optimized querysets and managers for payment operations.
 """
@@ -12,21 +12,23 @@ from django.db import models
 from django.utils import timezone
 from pydantic import BaseModel, ConfigDict, Field
 
-from django_cfg.modules.django_logging import get_logger
+import logging
 
-logger = get_logger("payment_managers")
+logger = logging.getLogger(__name__)
 
 
 class PaymentStatusUpdateFields(BaseModel):
     """
     Typed model for extra fields when updating payment status.
-    
+
     Ensures type safety and validation for payment status updates.
+    Uses Pydantic v2 for immutable validation.
     """
     model_config = ConfigDict(
         validate_assignment=True,
         extra="forbid",
-        str_strip_whitespace=True
+        str_strip_whitespace=True,
+        frozen=True  # Immutable
     )
 
     # Transaction related fields
@@ -34,8 +36,7 @@ class PaymentStatusUpdateFields(BaseModel):
     confirmations_count: Optional[int] = Field(None, ge=0, description="Number of blockchain confirmations")
 
     # Amount related fields
-    actual_amount_usd: Optional[Decimal] = Field(None, gt=0, description="Actual amount received in USD")
-    fee_amount_usd: Optional[Decimal] = Field(None, ge=0, description="Fee amount in USD")
+    actual_amount_crypto: Optional[Decimal] = Field(None, gt=0, description="Actual amount received in crypto")
 
     # Provider data
     provider_data: Optional[Dict[str, Any]] = Field(None, description="Provider-specific data")
@@ -47,33 +48,22 @@ class PaymentStatusUpdateFields(BaseModel):
 class PaymentQuerySet(models.QuerySet):
     """
     Optimized queryset for payment operations.
-    
+
     Provides efficient queries with proper indexing and select_related optimization.
     """
 
     def optimized(self):
         """
-        Prevent N+1 queries with select_related and prefetch_related.
-        
+        Prevent N+1 queries with select_related.
+
         Use this for admin interfaces and API responses.
         """
-        return self.select_related(
-            'user',
-            'currency',
-            'network'
-        ).prefetch_related(
-            'user__payment_balance',
-            'user__payment_transactions'
-        )
+        return self.select_related('user', 'currency')
 
     def by_status(self, status):
         """Filter by payment status with index optimization."""
         return self.filter(status=status)
 
-    def by_provider(self, provider):
-        """Filter by payment provider."""
-        return self.filter(provider=provider)
-
     def by_user(self, user):
         """Filter by user with proper indexing."""
         return self.filter(user=user)
@@ -81,7 +71,7 @@ class PaymentQuerySet(models.QuerySet):
     def by_amount_range(self, min_amount=None, max_amount=None):
         """
         Filter by USD amount range.
-        
+
         Args:
             min_amount: Minimum amount in USD (inclusive)
             max_amount: Maximum amount in USD (inclusive)
@@ -94,13 +84,9 @@ class PaymentQuerySet(models.QuerySet):
         return queryset
 
     def by_currency(self, currency_code):
-        """Filter by currency code."""
+        """Filter by currency code (e.g., USDTTRC20)."""
         return self.filter(currency__code=currency_code)
 
-    def by_network(self, network_code):
-        """Filter by blockchain network."""
-        return self.filter(network__code=network_code)
-
     # Status-based filters
     def completed(self):
         """Get completed payments."""
@@ -116,17 +102,25 @@ class PaymentQuerySet(models.QuerySet):
 
     def confirming(self):
         """Get payments awaiting confirmation."""
-        return self.filter(status__in=['confirming', 'confirmed'])
+        return self.filter(status='confirming')
+
+    def confirmed(self):
+        """Get confirmed payments (awaiting completion)."""
+        return self.filter(status='confirmed')
+
+    def partially_paid(self):
+        """Get partially paid payments (95% threshold)."""
+        return self.filter(status='partially_paid')
 
     def active(self):
         """Get active payments (not failed or completed)."""
-        return self.filter(status__in=['pending', 'confirming', 'confirmed'])
+        return self.filter(status__in=['pending', 'confirming', 'confirmed', 'partially_paid'])
 
     # Time-based filters
     def recent(self, hours=24):
         """
         Get payments from last N hours.
-        
+
         Args:
             hours: Number of hours to look back (default: 24)
         """
@@ -149,59 +143,24 @@ class PaymentQuerySet(models.QuerySet):
         return self.filter(created_at__date__gte=month_start)
 
     def expired(self):
-        """Get expired payments."""
-        now = timezone.now()
-        return self.filter(
-            expires_at__lte=now,
-            status__in=['pending', 'confirming']
-        )
-
-    def expiring_soon(self, hours=2):
-        """
-        Get payments expiring in the next N hours.
-        
-        Args:
-            hours: Hours until expiration (default: 2)
-        """
-        soon = timezone.now() + timezone.timedelta(hours=hours)
-        return self.filter(
-            expires_at__lte=soon,
-            expires_at__gt=timezone.now(),
-            status__in=['pending', 'confirming']
-        )
-
-    # Provider-specific filters
-    def nowpayments(self):
-        """Get NowPayments payments."""
-        return self.filter(provider='nowpayments')
-
-    def crypto_payments(self):
-        """Get cryptocurrency payments."""
-        return self.filter(currency__currency_type='crypto')
-
-    def fiat_payments(self):
-        """Get fiat currency payments."""
-        return self.filter(currency__currency_type='fiat')
+        """Get expired payments (status check only, no expires_at field)."""
+        return self.filter(status='expired')
 
     # Aggregation methods
     def total_amount(self):
         """Get total USD amount for queryset."""
         result = self.aggregate(total=models.Sum('amount_usd'))
-        return result['total'] or 0.0
+        return result['total'] or Decimal('0.00')
 
     def average_amount(self):
         """Get average USD amount for queryset."""
         result = self.aggregate(avg=models.Avg('amount_usd'))
-        return result['avg'] or 0.0
+        return result['avg'] or Decimal('0.00')
 
     def count_by_status(self):
         """Get count of payments grouped by status."""
         return self.values('status').annotate(count=models.Count('id')).order_by('status')
 
-    def count_by_provider(self):
-        """Get count of payments grouped by provider."""
-        return self.values('provider').annotate(count=models.Count('id')).order_by('provider')
-
     def count_by_currency(self):
         """Get count of payments grouped by currency."""
         return self.values('currency__code').annotate(count=models.Count('id')).order_by('currency__code')
@@ -209,11 +168,7 @@ class PaymentQuerySet(models.QuerySet):
     # Advanced queries
     def with_transactions(self):
         """Include related transaction data."""
-        return self.prefetch_related('user__payment_transactions')
-
-    def with_balance_info(self):
-        """Include user balance information."""
-        return self.select_related('user__payment_balance')
+        return self.prefetch_related('transaction_set')
 
     def requiring_confirmation(self):
         """Get payments that need blockchain confirmation."""
@@ -225,7 +180,7 @@ class PaymentQuerySet(models.QuerySet):
     def large_amounts(self, threshold=1000.0):
         """
         Get payments above threshold amount.
-        
+
         Args:
             threshold: USD amount threshold (default: $1000)
         """
@@ -234,7 +189,7 @@ class PaymentQuerySet(models.QuerySet):
     def small_amounts(self, threshold=10.0):
         """
         Get payments below threshold amount.
-        
+
         Args:
             threshold: USD amount threshold (default: $10)
         """
@@ -244,7 +199,7 @@ class PaymentQuerySet(models.QuerySet):
 class PaymentManager(models.Manager):
     """
     Manager for payment operations with optimized queries.
-    
+
     Provides high-level methods for common payment operations.
     """
 
@@ -277,20 +232,24 @@ class PaymentManager(models.Manager):
         """Get active payments."""
         return self.get_queryset().active()
 
+    def partially_paid(self):
+        """Get partially paid payments."""
+        return self.get_queryset().partially_paid()
+
+    # Aggregation methods
+    def count_by_status(self):
+        """Get count of payments grouped by status."""
+        return self.get_queryset().count_by_status()
+
+    def count_by_currency(self):
+        """Get count of payments grouped by currency."""
+        return self.get_queryset().count_by_currency()
+
     # User-based methods
     def by_user(self, user):
         """Get payments by user."""
         return self.get_queryset().by_user(user)
 
-    # Provider-based methods
-    def by_provider(self, provider):
-        """Get payments by provider."""
-        return self.get_queryset().by_provider(provider)
-
-    def nowpayments(self):
-        """Get NowPayments payments."""
-        return self.get_queryset().nowpayments()
-
     # Time-based methods
     def recent(self, hours=24):
         """Get recent payments."""
@@ -313,10 +272,6 @@ class PaymentManager(models.Manager):
         """Get expired payments."""
         return self.get_queryset().expired()
 
-    def expiring_soon(self, hours=2):
-        """Get payments expiring soon."""
-        return self.get_queryset().expiring_soon(hours)
-
     def requiring_confirmation(self):
         """Get payments needing confirmation."""
         return self.get_queryset().requiring_confirmation()
@@ -325,10 +280,10 @@ class PaymentManager(models.Manager):
     def get_stats(self, days=30):
         """
         Get payment statistics for the last N days.
-        
+
         Args:
             days: Number of days to analyze (default: 30)
-        
+
         Returns:
             dict: Statistics including totals, averages, and counts
         """
@@ -337,13 +292,13 @@ class PaymentManager(models.Manager):
 
         stats = {
             'total_payments': queryset.count(),
-            'total_amount_usd': queryset.total_amount(),
-            'average_amount_usd': queryset.average_amount(),
+            'total_amount_usd': float(queryset.total_amount()),
+            'average_amount_usd': float(queryset.average_amount()),
             'completed_payments': queryset.completed().count(),
             'pending_payments': queryset.pending().count(),
             'failed_payments': queryset.failed().count(),
+            'partially_paid_payments': queryset.partially_paid().count(),
             'by_status': list(queryset.count_by_status()),
-            'by_provider': list(queryset.count_by_provider()),
             'by_currency': list(queryset.count_by_currency()),
         }
 
@@ -355,32 +310,13 @@ class PaymentManager(models.Manager):
 
         return stats
 
-    def cleanup_expired(self, dry_run=True):
-        """
-        Mark expired payments as failed.
-        
-        Args:
-            dry_run: If True, only return count without making changes
-        
-        Returns:
-            int: Number of payments that would be/were updated
-        """
-        expired_payments = self.expired()
-        count = expired_payments.count()
-
-        if not dry_run and count > 0:
-            expired_payments.update(status='expired')
-            logger.info(f"Marked {count} payments as expired")
-
-        return count
-
     def get_user_payment_summary(self, user):
         """
         Get payment summary for a specific user.
-        
+
         Args:
             user: User instance
-        
+
         Returns:
             dict: User payment summary
         """
@@ -388,178 +324,17 @@ class PaymentManager(models.Manager):
 
         summary = {
             'total_payments': user_payments.count(),
-            'total_amount_usd': user_payments.total_amount(),
+            'total_amount_usd': float(user_payments.total_amount()),
             'completed_payments': user_payments.completed().count(),
             'pending_payments': user_payments.pending().count(),
             'failed_payments': user_payments.failed().count(),
             'last_payment_at': user_payments.first().created_at if user_payments.exists() else None,
-            'average_amount_usd': user_payments.average_amount(),
+            'average_amount_usd': float(user_payments.average_amount()),
         }
 
         return summary
 
     # Business logic methods
-    def mark_payment_completed(self, payment_id, actual_amount_usd=None, transaction_hash=None):
-        """
-        Mark payment as completed (business logic in manager).
-        
-        Args:
-            payment_id: Payment ID or instance
-            actual_amount_usd: Actual amount received
-            transaction_hash: Blockchain transaction hash
-        
-        Returns:
-            bool: True if payment was updated successfully
-        """
-        try:
-            if isinstance(payment_id, str):
-                payment = self.get(id=payment_id)
-            else:
-                payment = payment_id
-
-            # Validate payment can be completed
-            if payment.status not in ['pending', 'confirming', 'confirmed']:
-                logger.warning(f"Cannot complete payment in status {payment.status}", extra={
-                    'payment_id': str(payment.id),
-                    'current_status': payment.status
-                })
-                return False
-
-            # Update payment using centralized status update method
-            extra_fields = PaymentStatusUpdateFields(
-                actual_amount_usd=actual_amount_usd,
-                transaction_hash=transaction_hash
-            )
-
-            success = self.update_payment_status(payment, 'completed', extra_fields)
-            if not success:
-                return False
-
-            logger.info("Payment marked as completed", extra={
-                'payment_id': str(payment.id),
-                'user_id': payment.user.id,
-                'amount_usd': payment.amount_usd,
-                'actual_amount_usd': actual_amount_usd,
-                'transaction_hash': transaction_hash
-            })
-
-            return True
-
-        except Exception as e:
-            logger.error(f"Failed to mark payment as completed: {e}", extra={
-                'payment_id': str(payment_id) if hasattr(payment_id, 'id') else payment_id
-            })
-            return False
-
-    def mark_payment_failed(self, payment_id, reason=None, error_code=None):
-        """
-        Mark payment as failed (business logic in manager).
-        
-        Args:
-            payment_id: Payment ID or instance
-            reason: Failure reason
-            error_code: Error code for categorization
-        
-        Returns:
-            bool: True if payment was updated successfully
-        """
-        try:
-            if isinstance(payment_id, str):
-                payment = self.get(id=payment_id)
-            else:
-                payment = payment_id
-
-            # Prepare error info
-            provider_data = payment.provider_data.copy() if payment.provider_data else {}
-            if reason or error_code:
-                if 'error_info' not in provider_data:
-                    provider_data['error_info'] = {}
-                if reason:
-                    provider_data['error_info']['reason'] = reason
-                if error_code:
-                    provider_data['error_info']['code'] = error_code
-                provider_data['error_info']['failed_at'] = timezone.now().isoformat()
-
-            # Update payment using centralized status update method
-            extra_fields = PaymentStatusUpdateFields(
-                provider_data=provider_data if provider_data != payment.provider_data else None
-            )
-
-            success = self.update_payment_status(payment, 'failed', extra_fields)
-            if not success:
-                return False
-
-            logger.warning("Payment marked as failed", extra={
-                'payment_id': str(payment.id),
-                'user_id': payment.user.id,
-                'reason': reason,
-                'error_code': error_code
-            })
-
-            return True
-
-        except Exception as e:
-            logger.error(f"Failed to mark payment as failed: {e}", extra={
-                'payment_id': str(payment_id) if hasattr(payment_id, 'id') else payment_id
-            })
-            return False
-
-    def cancel_payment(self, payment_id, reason=None):
-        """
-        Cancel payment (business logic in manager).
-        
-        Args:
-            payment_id: Payment ID or instance
-            reason: Cancellation reason
-        
-        Returns:
-            bool: True if payment was cancelled successfully
-        """
-        try:
-            if isinstance(payment_id, str):
-                payment = self.get(id=payment_id)
-            else:
-                payment = payment_id
-
-            # Validate payment can be cancelled
-            if payment.status not in ['pending', 'confirming']:
-                logger.warning(f"Cannot cancel payment in status {payment.status}", extra={
-                    'payment_id': str(payment.id),
-                    'current_status': payment.status
-                })
-                return False
-
-            # Prepare cancellation info
-            provider_data = payment.provider_data.copy() if payment.provider_data else {}
-            if reason:
-                if 'cancellation_info' not in provider_data:
-                    provider_data['cancellation_info'] = {}
-                provider_data['cancellation_info']['reason'] = reason
-                provider_data['cancellation_info']['cancelled_at'] = timezone.now().isoformat()
-
-            # Update payment using centralized status update method
-            extra_fields = PaymentStatusUpdateFields(
-                provider_data=provider_data if provider_data != payment.provider_data else None
-            )
-
-            success = self.update_payment_status(payment, 'cancelled', extra_fields)
-            if not success:
-                return False
-
-            logger.info("Payment cancelled", extra={
-                'payment_id': str(payment.id),
-                'user_id': payment.user.id,
-                'reason': reason
-            })
-
-            return True
-
-        except Exception as e:
-            logger.error(f"Failed to cancel payment: {e}", extra={
-                'payment_id': str(payment_id) if hasattr(payment_id, 'id') else payment_id
-            })
-            return False
-
     def update_payment_status(
         self,
         payment,
@@ -568,12 +343,12 @@ class PaymentManager(models.Manager):
     ) -> bool:
         """
         Update payment status with automatic status_changed_at tracking.
-        
+
         Args:
             payment: Payment instance
             new_status: New status value
-            extra_fields: Typed extra fields to update
-            
+            extra_fields: Typed extra fields to update (Pydantic model)
+
         Returns:
             bool: True if status was updated
         """
@@ -585,16 +360,17 @@ class PaymentManager(models.Manager):
                 payment.status = new_status
                 payment.status_changed_at = timezone.now()
 
-                # Set completed_at if status changed to completed
-                if new_status == 'completed' and not payment.completed_at:
-                    payment.completed_at = timezone.now()
-
                 # Update fields list for save()
                 update_fields = ['status', 'status_changed_at', 'updated_at']
 
+                # Set completed_at if status changed to completed
+                if new_status == 'completed' and not payment.completed_at:
+                    payment.completed_at = timezone.now()
+                    update_fields.append('completed_at')
+
                 # Apply extra fields if provided
                 if extra_fields:
-                    # Validate extra fields
+                    # Validate extra fields (Pydantic v2)
                     if isinstance(extra_fields, dict):
                         extra_fields = PaymentStatusUpdateFields(**extra_fields)
 
@@ -602,7 +378,8 @@ class PaymentManager(models.Manager):
                     for field_name, field_value in extra_fields.model_dump(exclude_none=True).items():
                         if hasattr(payment, field_name):
                             setattr(payment, field_name, field_value)
-                            update_fields.append(field_name)
+                            if field_name not in update_fields:
+                                update_fields.append(field_name)
                         else:
                             logger.warning(f"Unknown field {field_name} ignored", extra={
                                 'payment_id': str(payment.id),
