@@ -164,7 +164,7 @@ APP_URL_MAP = {
     ],
     "django_cfg.apps.payments": [
         ("cfg/payments/", "django_cfg.apps.payments.urls"),
-        ("cfg/payments/admin/", "django_cfg.apps.payments.urls_admin"),
+        # Payments v2.0: No separate urls_admin (uses Django Admin only)
     ],
     "django_cfg.apps.ipc": [
         ("cfg/ipc/", "django_cfg.apps.ipc.urls"),
