@@ -18,6 +18,7 @@ from pydantic import BaseModel, Field, PrivateAttr, field_validator, model_valid
 from ...apps.ipc import DjangoCfgRPCConfig
 from ...models import (
     ApiKeys,
+    AxesConfig,
     CacheConfig,
     DatabaseConfig,
     DRFConfig,
@@ -230,7 +231,7 @@ class DjangoConfig(BaseModel):
 
     # === Security Configuration ===
     security_domains: List[str] = Field(
-        default_factory=list,
+        default_factory=lambda: ["localhost", "127.0.0.1"],
         description="Domains for automatic security configuration (CORS, SSL, etc.)",
     )
 
@@ -277,6 +278,12 @@ class DjangoConfig(BaseModel):
         description="Ngrok tunneling service configuration (for development/webhooks)",
     )
 
+    # === Security Configuration ===
+    axes: Optional["AxesConfig"] = Field(
+        default=None,
+        description="Django-Axes brute-force protection configuration (None = smart defaults)",
+    )
+
     # === Admin Interface Configuration ===
     unfold: Optional[UnfoldConfig] = Field(
         default=None,
