@@ -123,6 +123,15 @@ class SecurityBuilder:
             'SECURE_CONTENT_TYPE_NOSNIFF': False,
             'SECURE_BROWSER_XSS_FILTER': False,
             'X_FRAME_OPTIONS': 'SAMEORIGIN',
+
+            # === Django-Axes: Brute-force protection ===
+            **self._get_axes_settings(is_dev=True),
+
+            # === Authentication backends (django-axes + default) ===
+            'AUTHENTICATION_BACKENDS': [
+                'axes.backends.AxesStandaloneBackend',  # django-axes must be first
+                'django.contrib.auth.backends.ModelBackend',  # Default Django auth
+            ],
         }
 
     def _prod_mode_universal(self, security_domains: List[str]) -> Dict[str, Any]:
@@ -179,6 +188,15 @@ class SecurityBuilder:
             'SECURE_CONTENT_TYPE_NOSNIFF': True,
             'SECURE_BROWSER_XSS_FILTER': True,
             'X_FRAME_OPTIONS': 'DENY',
+
+            # === Django-Axes: Brute-force protection ===
+            **self._get_axes_settings(is_dev=False),
+
+            # === Authentication backends (django-axes + default) ===
+            'AUTHENTICATION_BACKENDS': [
+                'axes.backends.AxesStandaloneBackend',  # django-axes must be first
+                'django.contrib.auth.backends.ModelBackend',  # Default Django auth
+            ],
         }
 
     def _get_prod_allowed_hosts(self, domain_hosts: List[str]) -> List[str]:
@@ -308,6 +326,76 @@ class SecurityBuilder:
 
         return origins
 
+    def _get_axes_settings(self, is_dev: bool) -> Dict[str, Any]:
+        """
+        Get Django-Axes settings (custom config or smart defaults).
+
+        Args:
+            is_dev: Whether running in development mode
+
+        Returns:
+            Dictionary with Django-Axes settings
+        """
+        # If user provided custom AxesConfig, use it
+        if self.config.axes:
+            return self.config.axes.to_django_settings(
+                is_production=self.config.is_production,
+                debug=self.config.debug
+            )
+
+        # Otherwise, use smart defaults
+        return self._get_default_axes_settings(is_dev)
+
+    def _get_default_axes_settings(self, is_dev: bool) -> Dict[str, Any]:
+        """
+        Get default Django-Axes settings based on environment.
+
+        Args:
+            is_dev: Whether running in development mode
+
+        Returns:
+            Dictionary with default Django-Axes settings
+        """
+        if is_dev:
+            return {
+                'AXES_ENABLED': True,
+                'AXES_FAILURE_LIMIT': 10,  # More attempts in dev
+                'AXES_COOLOFF_TIME': 1,  # 1 hour lockout
+                'AXES_LOCK_OUT_AT_FAILURE': True,
+                'AXES_RESET_ON_SUCCESS': True,
+                # AXES_ONLY_USER_FAILURES deprecated in 8.0
+                'AXES_LOCKOUT_TEMPLATE': None,  # Use default lockout response
+                'AXES_LOCKOUT_URL': None,  # No custom lockout URL
+                'AXES_VERBOSE': True,  # Log lockout events in dev
+                'AXES_ENABLE_ACCESS_FAILURE_LOG': True,
+                'AXES_IPWARE_PROXY_COUNT': 1,
+                'AXES_IPWARE_META_PRECEDENCE_ORDER': [
+                    'HTTP_X_FORWARDED_FOR',
+                    'HTTP_X_REAL_IP',
+                    'REMOTE_ADDR',
+                ],
+            }
+        else:
+            return {
+                'AXES_ENABLED': True,
+                'AXES_FAILURE_LIMIT': 5,  # Stricter limit in production
+                'AXES_COOLOFF_TIME': 24,  # 24 hours lockout in production
+                'AXES_LOCK_OUT_AT_FAILURE': True,
+                'AXES_RESET_ON_SUCCESS': True,
+                # AXES_ONLY_USER_FAILURES deprecated in 8.0
+                'AXES_LOCKOUT_TEMPLATE': None,  # Use default lockout response
+                'AXES_LOCKOUT_URL': None,  # No custom lockout URL
+                'AXES_VERBOSE': False,  # Less verbose logging in production
+                'AXES_ENABLE_ACCESS_FAILURE_LOG': True,  # Log failures for security audit
+                # Proxy/Cloudflare support - get real IP from X-Forwarded-For
+                'AXES_IPWARE_PROXY_COUNT': 1,  # Number of proxies between client and server
+                'AXES_IPWARE_META_PRECEDENCE_ORDER': [
+                    'HTTP_X_FORWARDED_FOR',  # Cloudflare, nginx, traefik
+                    'HTTP_X_REAL_IP',        # Alternative proxy header
+                    'REMOTE_ADDR',           # Fallback to direct connection
+                ],
+            }
+
     def _normalize_domains(self, domains: List[str]) -> Dict[str, List[str]]:
         """
         Normalize domains in ANY format.
