@@ -30,9 +30,10 @@ from .api.keys import ApiKeys
 from .api.limits import LimitsConfig
 from .base.config import BaseConfig, BaseSettings
 from .base.module import BaseCfgAutoModule
-from .django.constance import ConstanceConfig, ConstanceField
 
 # Django-specific
+from .django.axes import AxesConfig
+from .django.constance import ConstanceConfig, ConstanceField
 from .django.environment import EnvironmentConfig
 from .django.openapi import OpenAPIClientConfig
 from .infrastructure.cache import CacheConfig
@@ -79,6 +80,7 @@ __all__ = [
     "ConstanceField",
     "OpenAPIClientConfig",
     "UnfoldConfig",
+    "AxesConfig",
     # Services
     "EmailConfig",
     "TelegramConfig",
