@@ -17,8 +17,10 @@ class DRFConfig(BaseModel):
     # Authentication
     authentication_classes: List[str] = Field(
         default_factory=lambda: [
+            'rest_framework_simplejwt.authentication.JWTAuthentication',
             'rest_framework.authentication.TokenAuthentication',
-            'rest_framework.authentication.SessionAuthentication',
+            # SessionAuthentication removed from defaults (requires CSRF)
+            # Add it manually in your config if you need Browsable API with session auth
         ],
         description="Default authentication classes"
     )
