@@ -10,6 +10,7 @@ from .field_config import (
     BooleanField,
     CurrencyField,
     DateTimeField,
+    ImageField,
     TextField,
     UserField,
 )
@@ -25,6 +26,7 @@ __all__ = [
     "BooleanField",
     "CurrencyField",
     "DateTimeField",
+    "ImageField",
     "TextField",
     "UserField",
 ]
