@@ -22,4 +22,12 @@ MODULES_REGISTRY = {
     "ExportMixin": ("django_cfg.modules.django_import_export", "ExportMixin"),
     "ImportMixin": ("django_cfg.modules.django_import_export", "ImportMixin"),
     "BaseResource": ("django_cfg.modules.django_import_export", "BaseResource"),
+
+    # Django Admin - Declarative Pydantic2 Configuration
+    # Note: PydanticAdmin is not in registry - import directly from .base to avoid AppRegistryNotReady
+    "AdminConfig": ("django_cfg.modules.django_admin", "AdminConfig"),
+    "FieldConfig": ("django_cfg.modules.django_admin", "FieldConfig"),
+    "FieldsetConfig": ("django_cfg.modules.django_admin", "FieldsetConfig"),
+    "ActionConfig": ("django_cfg.modules.django_admin", "ActionConfig"),
+    "WidgetRegistry": ("django_cfg.modules.django_admin", "WidgetRegistry"),
 }
