@@ -234,7 +234,7 @@ class SmartDefaults:
         return {
             'DEFAULT_AUTHENTICATION_CLASSES': [
                 'rest_framework_simplejwt.authentication.JWTAuthentication',
-                'rest_framework.authentication.SessionAuthentication',
+                # SessionAuthentication removed (requires CSRF)
             ],
             'DEFAULT_PERMISSION_CLASSES': [
                 'rest_framework.permissions.IsAuthenticated',
